function [ phi ] = AO(orbital,x,y,z,Z,ri)
%A0 gives the atomic orbital functions for the hydrogen model. The input
%values are the orbital (e.g. '1s') up to the 2pz orbital and the atomic 
%number (Kernaladungszahl)Z as well as the vectors x, y and z of the
%position of the electron for which the function will be calculated. The
%argument ri is the position vector [xi,yi,zi] of the corresponding nucleus

a0 = 5.29*10^(-11); %Bohr raduis in meters

r = sqrt((x-ri(1)).^2+(y-ri(2)).^2+(z-ri(3)).^2);

o = orbital;
e = exp(-(Z*r)/(2*a0));
v = 0.25*sqrt(Z^5/(2*pi()*a0^5));
vd = (1/81)*sqrt(Z^7/(pi*a0^7)).*exp(-(Z*r)/(3*a0));

if strcmp('1s',o)
    phi = sqrt(Z^3/(pi()*a0^3))*exp(-(Z*r)/a0);
elseif strcmp('2s',o)
    phi = 0.25*sqrt(Z^3/(2*pi()*a0^3)).*(2-(Z*r)/a0).*e;
elseif strcmp('2px',o)
    phi = v.*e.*(x-ri(1));
elseif strcmp('2py',o)
    phi = v.*e.*(y-ri(2));
elseif strcmp('2pz',o)
    phi = v.*e.*(z-ri(3));  
elseif strcmp('3dzz',o)
    phi = vd/sqrt(6).*(3*(z-ri(3)).^2-r.^2); 
elseif strcmp('3dxz',o)
    phi = sqrt(2)*vd.*(x-ri(1)).*(z-ri(3));  
elseif strcmp('3dyz',o)
    phi = sqrt(2)*vd.*(y-ri(2)).*(z-ri(3));
elseif strcmp('3dx-y',o)
    phi = sqrt(2)*0.5*vd.*((x-ri(1)).^2-(z-ri(3)).^2); 
elseif strcmp('3dxy',o)
    phi = sqrt(2)*vd.*(x-ri(1)).*(y-ri(2));  
end   
    
end
    



