Step = 250; %for the integration grid <= 250 for a reasonable time
D = 1.5; %Distance for the integration from the center of the atom in multiples of the Bohr radius
a0 = 5.29*10E-11; %Bohr radius

numorbit = 12 ; %number of mo functions used for calculation
orbit = {'1s','2s','2px','2py','2pz','3dzz','3dxz','3dyz','3dx-y','3dxy'}; %names of the used mo functions


%Positions for the H2O molecule
hx = 0.076697*10^(-9); %[m],x-distance of the H atom to the O atom
hy = 0.059385*10^(-9); %[m],y-distance of the H atom to the O atom
rH = [-hx,hy,0;hx,hy,0]; %positions of the H atoms
rO = [0,0,0]; %position of the O atom



x = a0*linspace(-D,D,Step);  %position-vectors for the calculation of the wavefunctions
y0 = ones(1,Step );           %with length 2*D*a0 in 'Step' steps
z0 = y0;
d = 2*D*a0/(Step);         %distance of one Step
dV = d^3;                  %integration volume (cube)


%calculation of the wave functions p
p = zeros(Step,Step,Step,numorbit); %initial matrix for saving the wavefunctions
%andcalculation of the hamiltonian acting on the wavfunctions
Hp = zeros(Step,Step,Step,numorbit); %x,y,z

Z = 7.7; %values of Z calculated with slaters' rule
o = 1; %1s at O
for n = 1:Step
    y = x(n)*y0;
    for m = 1:Step
        z = x(m)*z0;      
        p(:,n,m,o) = AO(orbit(o),x,y,z,Z,rO);
        Hp(:,n,m,o) = hamiltonian_H2O(orbit(o),x,y,z,Z,3,rH(1,:),rH(2,:),rO);
    end
end 

Z = 4.55; %2s and 2p at O
for o = 2:5
for n = 1:Step
    y = x(n)*y0;
    for m = 1:Step
        z = x(m)*z0;      
        p(:,n,m,o) = AO(orbit(o),x,y,z,Z,rO);
        Hp(:,n,m,o) = hamiltonian_H2O(orbit(o),x,y,z,Z,3,rH(1,:),rH(2,:),rO);
    end
end
end

if numorbit > 7
Z = 1.75; %3d at O
for o = 6:10
for n = 1:Step
    y = x(n)*y0;
    for m = 1:Step
        z = x(m)*z0;      
        p(:,n,m,o) = AO(orbit(o),x,y,z,Z,rO);
        Hp(:,n,m,o) = hamiltonian_H2O(orbit(o),x,y,z,Z,3,rH(1,:),rH(2,:),rO);
    end
end
end
end

Z = 1; %1s at the two H atoms
for o = 1:2
for n = 1:Step
    y = x(n)*y0;
    for m = 1:Step
        z = x(m)*z0;      
        p(:,n,m,o+numorbit-2) = AO('1s',x,y,z,Z,rH(o,:));
        Hp(:,n,m,o+numorbit-2) = hamiltonian_H2O('1s',x,y,z,Z,o,rH(1,:),rH(2,:),rO);
    end
end
end

%calculation of the overlap matrix S
S = zeros(numorbit);

for n = 1:numorbit
    for m = 1:numorbit
        S(n,m) = sum(sum(sum((p(:,:,:,n).*p(:,:,:,m)),1),2),3)*dV;
    end
end

S0 = abs(S) >= 10^-(6); %deleting very small entries
S = S.*S0;



%calculation of the hamiltonian Matrix
H = zeros(numorbit);

for n = 1:numorbit
    for m = 1:numorbit
        H(n,m) = sum(sum(sum((p(:,:,:,n).*Hp(:,:,:,m)),1),2),3)*dV;
    end
end


H = 6.24150913*10^(18) *H; %changing unit of H to eV

H0 = abs(H) >= 10E-6; %deleting very small entries
H = H.*H0;
H = 1/2*(H+transpose(H)); %symmetrising H


M = S\H; 
e = eig(M); %calculation of the eigenenergies

