function [ hphi ] = hamiltonian_H2O( orbital,x,y,z,Z,nuc,rH1,rH2,rO )
%HAMILTONIAN molecular orbital hamiltoniam matrix for the H2O molecule
%nuc chooses the nucleus (1 = H1, 2 = H2, 3 = O). rH1 ia the position of the first H nucleus rH2 the position of the second
%H nucleus and rO the position of O

a0 = 5.29E-11; %Bohr raduis in meters
hbar = 1.05457266E-34;
eps0 = 8.854187817E-12;
me = 9.1093897E-31; %electron mass
ec = 1.60217733E-19; %elementary charge
v1 = 0.5*hbar^2/me; %prefactor fot the kinetic part
v2 = ec^2/(4*pi*eps0); %Coulomb constant

if nuc == 1
    ri = rH1;
    ZO = 4.55;
    ZH1 = 1;
    ZH2 = 0.7;
elseif nuc == 2
    ri = rH2;
    ZO = 4.55;
    ZH1 = 0.7;
    ZH2 = 1;  
elseif nuc == 3
    ri = rO;
    ZO = Z;
    ZH1 = 0.7;
    ZH2 = 0.7;
end


hphi = -v1*laplaceAO(orbital,x,y,z,Z,ri) -... 
       ZH1*v2*AO(orbital,x,y,z,Z,ri)./abs(sqrt((x-rH1(1)).^2+(y-rH1(2)).^2+(z-rH1(3)).^2))-...
       ZH1*v2*AO(orbital,x,y,z,Z,ri)./abs(sqrt((x-rH2(1)).^2+(y-rH2(2)).^2+(z-rH2(3)).^2))-...
       ZO*v2*AO(orbital,x,y,z,Z,ri)./abs(sqrt((x-rO(1)).^2+(y-rO(2)).^2+(z-rO(3)).^2));

end

