function [ phi ] = laplaceAO( orbital,x,y,z,Z,ri )
%LAPLACEAO 	gives the atomic orbital function after the laplacian operator
%has acted on it
%The input values are the orbital (e.g. '1s') up to the 2pz orbital and the
%atomic number (Kernaladungszahl)Z as well as the vectors x, y and z of the
%position of the electron for which the function will be calculated. The
%argument ri is the position vector [xi,yi,zi] of the corresponding nucleus

a0 = 5.29*10^(-11); %Bohr raduis in meters

r = sqrt((x-ri(1)).^2+(y-ri(2)).^2+(z-ri(3)).^2);

o = orbital;
e = exp(-(Z*r)/(2*a0));
v = 0.25*sqrt(Z^5/(2*pi()*a0^5));
v1 = sqrt(Z^7/(2^5*pi()*a0^7)).*(Z*r/(4*a0)-2);
c = Z/(3*a0);
vd = 1/81*sqrt(Z^7/(pi*a0^7));
vd1 = c*r.*exp(-c*r).*(c*r-6);



if strcmp('1s',o)
    phi = sqrt(Z^5/(pi()*a0^5))*(Z/a0-2./r).*exp(-(Z*r)/a0);
elseif strcmp('2s',o)
    phi = v.*(-(Z^2*r)/(4*a0^2)+(5*Z)/(2*a0)-4./r).*e;
elseif strcmp('2px',o)
    phi = v1.*e.*(x-ri(1))./r;
elseif strcmp('2py',o)
    phi = v1.*e.*(y-ri(2))./r;
elseif strcmp('2pz',o)
    phi = v1.*e.*(z-ri(3))./r;
elseif strcmp('3dzz',o)
    phi = vd/sqrt(6)*vd1.*(3*(z-ri(3)).^2-r.^2); 
elseif strcmp('3dxz',o)
    phi = sqrt(2)*vd*vd1.*(x-ri(1)).*(z-ri(3))./r.^2;  
elseif strcmp('3dyz',o)
    phi = sqrt(2)*vd*vd1.*(y-ri(2)).*(z-ri(3))./r.^2;
elseif strcmp('3dx-y',o)
    phi = sqrt(2)*vd*vd1.*((x-ri(1)).^2-(z-ri(3)).^2)./r.^2; 
elseif strcmp('3dxy',o)
    phi = sqrt(2)*2*vd*vd1.*(x-ri(1)).*(y-ri(2))./r.^2;  
end

